[![GitHub Actions Workflow Status](https://img.shields.io/github/actions/workflow/status/AllenInstitute/TEM_comms/test.yaml)](https://github.com/AllenInstitute/TEM_comms/actions)
[![PyPI - Version](https://img.shields.io/pypi/v/pigeon-tem-comms)](https://pypi.org/project/pigeon-tem-comms/)

# TEM Comms

TEM Comms is a set of [Pydantic](https://docs.pydantic.dev/latest/) models to be used as messages with [Pigeon](https://github.com/AllenInstitute/pigeon) for the [Allen Institute's](https://alleninstitute.org/) next generation transmission electron microscope (TEM) [image acquisition system](https://alleninstitute.github.io/TEM_architecture/).